package com.simuwang.manage.service.impl;

import com.simuwang.base.common.support.MybatisPage;
import com.simuwang.base.mapper.daq.CompanyEmailConfigMapper;
import com.simuwang.base.mapper.daq.CompanyEmailSendHistoryMapper;
import com.simuwang.base.pojo.dos.CompanyEmailConfigDO;
import com.simuwang.base.pojo.dos.CompanyEmailPageDO;
import com.simuwang.base.pojo.dos.CompanyEmailSendHistoryDO;
import com.simuwang.base.pojo.dos.ContactInformationDO;
import com.simuwang.base.pojo.dto.query.CompanyEmailHistoryPageQuery;
import com.simuwang.base.pojo.dto.query.CompanyEmailPageQuery;
import com.simuwang.base.pojo.vo.CompanyEmailConfigVO;
import com.simuwang.base.pojo.vo.CompanyEmailPageVO;
import com.simuwang.base.pojo.vo.CompanyEmailSendHistoryVO;
import com.simuwang.base.pojo.vo.IdVO;
import com.simuwang.manage.service.CompanyEmailSendHistoryService;
import com.simuwang.manage.service.ContactInformationService;
import com.simuwang.shiro.utils.UserUtils;
import com.smppw.common.pojo.ResultVo;
import com.smppw.common.pojo.enums.status.ResultCode;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

/**
 * FileName: CompanyEmailSendHistoryServiceImpl
 * Author:   chenjianhua
 * Date:     2024/9/9 10:06
 * Description: ${DESCRIPTION}
 */
@Service
public class CompanyEmailSendHistoryServiceImpl implements CompanyEmailSendHistoryService {
    @Autowired
    private CompanyEmailSendHistoryMapper companyEmailSendHistoryMapper;
    @Autowired
    private ContactInformationService contactInformationService;

    @Autowired
    private CompanyEmailConfigMapper companyEmailConfigMapper;
    @Override
    public MybatisPage<CompanyEmailPageVO> searchCompanyEmail(CompanyEmailPageQuery companyEmailPageQuery) {
        List<CompanyEmailPageDO> dataList = companyEmailSendHistoryMapper.searchCompanyEmailList(companyEmailPageQuery);
        List<CompanyEmailPageVO> voList = dataList.stream().map(CompanyEmailPageDO::toVo).collect(Collectors.toList());
        long total = companyEmailSendHistoryMapper.countCompanyEmailList(companyEmailPageQuery);
        return MybatisPage.of(total, voList);
    }

    @Override
    public MybatisPage<CompanyEmailSendHistoryVO> searchEmailHistory(CompanyEmailHistoryPageQuery companyEmailHistoryPageQuery) {
        List<CompanyEmailSendHistoryDO> dataList = companyEmailSendHistoryMapper.searchEmailHistory(companyEmailHistoryPageQuery);
        List<CompanyEmailSendHistoryVO> voList = dataList.stream().map(CompanyEmailSendHistoryDO::toVo).collect(Collectors.toList());
        long total = companyEmailSendHistoryMapper.countCompanyEmailhistory(companyEmailHistoryPageQuery);
        return MybatisPage.of(total, voList);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ResultVo deleteEmail(List<Integer> idList) {
        ResultVo vo = new ResultVo<>(ResultCode.DELETE_SUCCESS.getCode());
        for(Integer id : idList){
            ContactInformationDO contactInformationDO = contactInformationService.selectById(id);
            List<String> emailList = new ArrayList<>();
            vo = contactInformationService.deleteById(contactInformationDO.getId());
            if(vo.getCode() != ResultCode.DELETE_SUCCESS.getCode()){
                return vo;
            }
            if(emailList.size() > 0){
                companyEmailSendHistoryMapper.deleteEmailHistory(contactInformationDO.getCompanyId(),contactInformationDO.getContactEmail());
            }
        }
        vo.setData(true);
        return vo;
    }

    @Override
    public void deleteEmailHistory(List<Integer> idList) {
        Integer userId = UserUtils.getLoginUser().getUserId();
        companyEmailSendHistoryMapper.deleteEmailHistoryByIds(idList,userId);
    }

    @Override
    public CompanyEmailConfigVO searchEmailConfig(IdVO idVO) {
        CompanyEmailConfigDO configDO = companyEmailConfigMapper.selectCompanyEmailConfigById(idVO.getId());
        CompanyEmailConfigVO configVO = configDO.toVO();
        return configVO;
    }
}
